#
# spec file for package perl-Inline
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Inline
Version:        0.80
Release:        lp151.2.1
%define cpan_name Inline
Summary:        Write Perl Subroutines in Other Programming Languages
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Inline/
Source0:        http://www.cpan.org/authors/id/I/IN/INGY/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Warn) >= 0.23
%{perl_requires}
# MANUAL BEGIN
Requires:       gcc
Requires:       make
Provides:       perl-Inline-C = 0.20
Obsoletes:      perl-Inline-C < 0.20
# MANUAL END

%description
The Inline module allows you to put source code from other programming
languages directly "inline" in a Perl script or module. The code is
automatically compiled as needed, and then loaded for immediate access from
Perl.

Inline saves you from the hassle of having to write and compile your own
glue code using facilities like XS or SWIG. Simply type the code where you
want it and run your Perl as normal. All the hairy details are handled for
you. The compilation and installation of your code chunks all happen
transparently; all you will notice is the delay of compilation on the first
run.

The Inline code only gets compiled the first time you run it (or whenever
it is modified) so you only take the performance hit once. Code that is
Inlined into distributed modules (like on the CPAN) will get compiled when
the module is installed, so the end user will never notice the compilation
time.

Best of all, it works the same on both Unix and Microsoft Windows. See the
Inline- Support manpage for support information.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f -print0 | xargs -0 chmod 644

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes CONTRIBUTING example LICENSE README

%changelog
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.80
  see /usr/share/doc/packages/perl-Inline/Changes
* Fri Nov 23 2012 bwiedemann@suse.com
- require make+gcc to avoid
  https://rt.cpan.org/Public/Bug/Display.html?id=81375
* Wed Feb  8 2012 vcizek@suse.com
- update to 0.50
    Inline.pm - Bump version number to 0.50
    Inline.pm - Bring version numbering into line with recommendations made in
    http://perldoc.perl.org/perlmodstyle.html#Version-numbering
    Inline.pm - Rename create_config_file()'s private @INC to @_inc.
    (This is just to avoid any confusion that we might be
    messing with @INC.)
  - In creating @_inc, we now additionally grep for the location
    of Parse::RecDescent - in case it's in a different PERL5LIB
    location to Inline (as generally happens with cpan smokers -
    but could happen anywhere).
  - Update copyright dates throughout.
    C/t - Make alterations to all of the '.t' files in C/t (except
    for 00init.t). This is in reponse to ticket 73448, which
    raised the possibility that Inline may get built with the
    PERL_INSTALL_ROOT environment variable set.
    Inline.pod - mention the need to make provision for the
    PERL_INSTALL_ROOT environment variable iff it has
    been set.
    As the result of input from David Oswald:
    Inline.pod - Changes relating to "CONFIGURE_REQUIRES" and fix
    typo reported in ticket 73108.
    Inline-FAQ.pod - Changes relating to "CONFIGURE_REQUIRES"
    Inline.pm - Bump version to 0.49_01
    lib/Inline/MakeMaker.pm - Bump version to 0.49_01
* Thu Dec  8 2011 vcizek@suse.com
- update to 0.49
  * Inline.pm - small alteration to M19_usage_language error message
  - Have the config file re-created *before* we croak with
    M19_usage_language(). (Re-creating the config file should
    alleviate the need to croak, thus allowing the script to
    complete successfully.) Thanks to Patrick LeBoutillier for
    the patch, and to David Oswald for pursuing this.
- licence correction (same as Perl)
* Sun Nov 20 2011 coolo@suse.com
- obsolete perl-Inline-C correctly
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Tue Feb 22 2011 vcizek@novell.com
- update to 0.48
  * new buildrequires - Test::Warn
  * Makefile.PL - Change the Test::Warn dependency from 0.22 to 0.21 and
    specify it in top-level Makefile.PL instead of in C/Makefile.PL.
  * Changes to Inline::C test suite - see C/Changes.
* Mon Jan 24 2011 vcizek@novell.com
- update to 0.47
  Version 0.47 released to CPAN. No changes from 0.46_02
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Feb 16 2010 coolo@novell.com
- update to 0.46
  * Changes to Inline.pm, denter.pm, and Inline.pod relating to "fixing" untainting
  (to the extent that untainting of -T inline scripts works as documented).
  * C/C.pod - document that *fully qualified* paths for LIBS, INC, TYPEMAPS and MYEXTLIB
    are needed. (RT ticket 5207)
  * Inline.pm - remove "defined" from "defined %%main::Inline::Config::" as that usage
    causes a deprecation warning with perl-5.11 and later. (RT ticket 53227)
  * Inline.pm - fix sub push_overrides (RT ticket 49669)
    This change responsible for "Subroutine Inline::C::get_parser redefined"
    warnings that can occur during build stage under certain circumstances.
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Tue Jan 20 2009 anicka@suse.cz
- update to 0.45
  * Apply patch to Inline.pm that addresses a problem with
    whitespace occurring in the name of the build directory.
  * Fix ParseRegExp.pm.
  * Fix (in Inline.pm) problem regarding the calling of the same
    script from different builds of perl.
  * Allow Inline::install() subroutine to apply to languages other
    than C and CPP.
  * Fix C/Makefile.PL so that the C compiler can still be found
    when $Config{cc} reports something like /some/place/cc.
  * In C/C.pm, allow for the calling of multiple typemaps, and
    have the "No Inline C functions bound to Perl" warning
    specify the file for which no bindings were found
  * Minor doc fixes.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Oct 16 2003 mmj@suse.de
- Don't build as root
- Use %%perl_make_install
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 14 2003 mmj@suse.de
- Use vendor_install target and friends
* Tue Jul  1 2003 mmj@suse.de
- Use %%perl_process_packlist
* Wed Jun 18 2003 coolo@suse.de
- package directories
* Tue May 13 2003 mmj@suse.de
- Package all files
* Mon Dec  2 2002 mmj@suse.de
- Update to 0.44
* Mon Jul 29 2002 mls@suse.de
- Fixed neededforbuild for perl-5.8.0
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Wed Aug  1 2001 grimmer@suse.de
- update to 0.43
* Fri Jun 22 2001 grimmer@suse.de
- added missing Requires:
* Fri Jun 22 2001 grimmer@suse.de
- initial build (version 0.42), required for latest
  version of grepmail (probably other packages will need it, too)
